@@ -63,14 +63,14 @@
 #undef stat
 #endif
 
-class KDirSelectDialog::Private
+class Q_DECL_HIDDEN KDirSelectDialog::Private
 {
 public:
     Private(bool localOnly, KDirSelectDialog *parent)
         : m_parent(parent),
           m_localOnly(localOnly),
           m_comboLocked(false),
-          m_urlCombo(0)
+          m_urlCombo(nullptr)
     {
     }
 
@@ -271,7 +271,7 @@ void KDirSelectDialog::Private::slotDelete()
 
 void KDirSelectDialog::Private::slotProperties()
 {
-    KPropertiesDialog *dialog = 0;
+    KPropertiesDialog *dialog = nullptr;
     dialog = new KPropertiesDialog(m_treeView->selectedUrl(), this->m_parent);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->show();
@@ -306,7 +306,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly,
     topLayout->addWidget(buttonBox);
 
     QHBoxLayout *hlay = new QHBoxLayout(page);
-    hlay->setMargin(0);
+    hlay->setContentsMargins(0, 0, 0, 0);
     QVBoxLayout *mainLayout = new QVBoxLayout();
     d->m_actions = new KActionCollection(this);
     d->m_actions->addAssociatedWidget(this);
